This patch seems a logical follow up for 25969 on VMS (cando stuff)

diff -ruN perl-blead/vms/vmsish.h perl-current/vms/vmsish.h
--- perl-blead/vms/vmsish.h     Sat Oct 22 19:11:49 2005
+++ perl-current/vms/vmsish.h   Sat Nov  5 12:18:02 2005
@@ -872,7 +872,7 @@
 int     my_sigismember (sigset_t *, int);
 int     my_sigprocmask (int, sigset_t *, sigset_t *);
 #endif
-I32    Perl_cando_by_name (pTHX_ I32, Uid_t, const char *);
+I32    Perl_cando_by_name (pTHX_ I32, bool, const char *);
 int    Perl_flex_fstat (pTHX_ int, Stat_t *);
 int    Perl_flex_lstat (pTHX_ const char *, Stat_t *);
 int    Perl_flex_stat (pTHX_ const char *, Stat_t *);

(also attached)
HTH +
Good luck,

Abe
diff -ruN perl-blead/vms/vmsish.h perl-current/vms/vmsish.h
--- perl-blead/vms/vmsish.h	Sat Oct 22 19:11:49 2005
+++ perl-current/vms/vmsish.h	Sat Nov  5 12:18:02 2005
@@ -872,7 +872,7 @@
 int     my_sigismember (sigset_t *, int);
 int     my_sigprocmask (int, sigset_t *, sigset_t *);
 #endif
-I32	Perl_cando_by_name (pTHX_ I32, Uid_t, const char *);
+I32	Perl_cando_by_name (pTHX_ I32, bool, const char *);
 int	Perl_flex_fstat (pTHX_ int, Stat_t *);
 int	Perl_flex_lstat (pTHX_ const char *, Stat_t *);
 int	Perl_flex_stat (pTHX_ const char *, Stat_t *);

Reply via email to
diff -ruN perl-blead/vms/vms.c perl-current/vms/vms.c
--- perl-blead/vms/vms.c        Wed Oct 26 15:54:10 2005
+++ perl-current/vms/vms.c      Sat Nov  5 12:16:39 2005
@@ -9240,7 +9240,7 @@
  * subset of the applicable information.
  */
 bool
-Perl_cando(pTHX_ Mode_t bit, Uid_t effective, const Stat_t *statbufp)
+Perl_cando(pTHX_ Mode_t bit, bool effective, const Stat_t *statbufp)
 {
   char fname_phdev[NAM$C_MAXRSS+1];
 #if __CRTL_VER >= 80200000 && !defined(__VAX)
@@ -9293,9 +9293,9 @@
 /*}}}*/
 
 
 /*{{{I32 cando_by_name(I32 bit, Uid_t effective, char *fname)*/
 I32
-Perl_cando_by_name(pTHX_ I32 bit, Uid_t effective, const char *fname)
+Perl_cando_by_name(pTHX_ I32 bit, bool effective, const char *fname)
 {
   static char usrname[L_cuserid];
   static struct dsc$descriptor_s usrdsc =
@@ -9293,9 +9293,9 @@
 
 
-/*{{{I32 cando_by_name(I32 bit, Uid_t effective, char *fname)*/
+/*{{{I32 cando_by_name(I32 bit, bool effective, char *fname)*/
 I32
-- 
This thread is supposed to be about what it means - not about the 
implementation. I am painfully aware of the implementation issues.
                                    -- Nick Ing-Simmons on p5p @ 2003-05-22
diff -ruN perl-blead/vms/vms.c perl-current/vms/vms.c
--- perl-blead/vms/vms.c	Wed Oct 26 15:54:10 2005
+++ perl-current/vms/vms.c	Sat Nov  5 12:16:39 2005
@@ -9240,7 +9240,7 @@
  * subset of the applicable information.
  */
 bool
-Perl_cando(pTHX_ Mode_t bit, Uid_t effective, const Stat_t *statbufp)
+Perl_cando(pTHX_ Mode_t bit, bool effective, const Stat_t *statbufp)
 {
   char fname_phdev[NAM$C_MAXRSS+1];
 #if __CRTL_VER >= 80200000 && !defined(__VAX)
@@ -9293,9 +9293,9 @@
 /*}}}*/
 
 
 /*{{{I32 cando_by_name(I32 bit, Uid_t effective, char *fname)*/
 I32
-Perl_cando_by_name(pTHX_ I32 bit, Uid_t effective, const char *fname)
+Perl_cando_by_name(pTHX_ I32 bit, bool effective, const char *fname)
 {
   static char usrname[L_cuserid];
   static struct dsc$descriptor_s usrdsc =
@@ -9293,9 +9293,9 @@
 
 
-/*{{{I32 cando_by_name(I32 bit, Uid_t effective, char *fname)*/
+/*{{{I32 cando_by_name(I32 bit, bool effective, char *fname)*/
 I32